@@ -82,13 +82,13 @@ expr_t_onesample <- function(data,
                              x,
                              type = "parametric",
                              test.value = 0,
+                             k = 2L,
+                             conf.level = 0.95,
+                             conf.type = "norm",
                              bf.prior = 0.707,
                              robust.estimator = "onestep",
                              effsize.type = "g",
-                             conf.level = 0.95,
-                             conf.type = "norm",
-                             nboot = 100,
-                             k = 2L,
+                             nboot = 100L,
                              stat.title = NULL,
                              ...) {
 
